#-----------------------------------------------------------------------
# body.py
# 
# Z knihy Sedgewick, Wayne, Dondero,
# http://introcs.cs.princeton.edu/python/code/
# upravil J.Kybic pro použití standardních knihoven, 2017
#-----------------------------------------------------------------------

import matplotlib.pyplot as plt # pro zobrazování a grafy
import numpy as np              # Numeric Python
import math

class Body:

    # Construct a new Body object whose position is specified by
    # Vector object r, whose velocity is specified by Vector object
    # v, and whose mass is specified by float mass. 'color' is a matplotlib color code
    # for visualization

    def __init__(self, r, v, mass,color='k'):
        self._r = r        # Position
        self._v = v        # Velocity
        self._mass = mass  # Mass
        self.color=color

    # Move self by applying the force specified by Vector object
    # f for the number of seconds specified by float dt.

    def move(self, f, dt):
        a = f * (1. / self._mass)
        self._v = self._v + a*dt
        self._r = self._r + self._v*dt

    # Return the force between Body objects self and other.

    def forceFrom(self, other):
        G = 6.67e-11
        delta = other._r - self._r
        dist3 = np.dot(delta,delta)**(-1.5) # |r|^{-3}
        return delta* (G * self._mass * other._mass) * dist3

    # Draw self to standard draw.

    def draw(self):
        plt.plot(self._r[0], self._r[1],self.color+'.')

