# Simulace házení 
# Jan Kybic, 2017


import numpy as np              # Numeric Python
import matplotlib.pyplot as plt # pro zobrazování a grafy
import math

def hod(uhel,rychlost,dt=0.01,tmax=1000):
  """ Hodíme předmět pod úhlem 'uhel' ve stupních s vodorovnou osou z bodu (0,0) rychlostí 'rychlost' [m/s].
      Vrátí pole 'xs' a 'ys'
      souřadnic 'x','y' v časech 0,dt,2dt,... dokud 'y>=0' a t<tmax """
  xs=[]
  ys=[]
  x=0. ; y=0. ; t=0.
  anglerad=uhel*math.pi/180.
  vx=math.cos(anglerad)*rychlost
  vy=math.sin(anglerad)*rychlost
  while y>=0. and t<tmax:
    xs+=[x]
    ys+=[y]
    t+=dt
    x+=dt*vx
    y+=dt*vy
    vy-=9.81*dt # standard gravitational acceleration
    #print("x=",x," y=",y," vy=",vy, " vx=",vx)
  return xs,ys

def test_hod():
  rychlost=10.
  plt.figure(1)
  plt.clf()
  #plt.plot(0,0,'bo')
  #plt.plot([0,15],[0,0],'b-') # nakresli zemi
  for uhel in [10,20,30,40,50,60,70,80]:
    xs,ys=hod(uhel, rychlost)
    plt.plot(xs,ys,label='%3.0f' % uhel)
  plt.xlabel('x [m]')
  plt.ylabel('y [m]')
  plt.legend(loc='top right')
  plt.savefig('figs/hody.pdf')
  plt.show()

if __name__=='__main__':
  test_hod()
  


    
